@@ -435,7 +435,6 @@ BOOL isEnglishNumberAlphabet(unsigned char c) {
 }
 
 - (void) showErrorMsg:(NSString *) msg {
-    [Answers logCustomEventWithName:@"Long Screenshot" customAttributes:@{@"failed" : msg}];
     NSBeginAlertSheet(NSLocalizedString(@"Long Screenshot Error!", @"Sheet Title"),
                       NSLocalizedString(@"Confirm", @"Default Button"),
                       nil,
@@ -549,7 +548,6 @@ BOOL isEnglishNumberAlphabet(unsigned char c) {
                     [self performSelectorOnMainThread:@selector(takeScreenShot:) withObject:screenArray waitUntilDone:YES];
                     
                     // last page reached, break for infinite while loop
-                    [Answers logCustomEventWithName:@"Long Screenshot" customAttributes:@{@"pagecount" : [NSNumber numberWithInt: (pageCount+1)]}];
                     break;
                 }
             } else {
@@ -695,7 +693,6 @@ BOOL isEnglishNumberAlphabet(unsigned char c) {
         [screenArray removeAllObjects];
         [pool release];
         
-        [Answers logCustomEventWithName:@"Long Screenshot" customAttributes:@{@"action" : @"Capture successfully!"}];
         [_longScreenshotWindow endEditingFor:nil];
         [NSApp endSheet:_longScreenshotWindow];
         [_longScreenshotWindow orderOut:self];
@@ -735,13 +732,12 @@ BOOL isEnglishNumberAlphabet(unsigned char c) {
     if (![self isConnected]) return;
     
     if([[self getTerminalBottomLine] containsString:@" 瀏覽 第"]){
-        [Answers logCustomEventWithName:@"Long Screenshot" customAttributes:@{@"action" : @"pressed ok!"}];
         // show working panel
         if (!_longScreenshotWindow) {
             [NSBundle loadNibNamed:kLongScreenshotPanelNibFilename owner:self];
         }
         [NSApp beginSheet:_longScreenshotWindow
-           modalForWindow:_window
+           modalForWindow:nil
             modalDelegate:nil
            didEndSelector:NULL
               contextInfo:nil];
@@ -756,7 +752,6 @@ BOOL isEnglishNumberAlphabet(unsigned char c) {
 }
 
 - (void)showNotificationWindow:(NSString *)titleMsg withSheetMsg:(NSString *)sheetMsg{
-    [Answers logCustomEventWithName:@"Long Screenshot" customAttributes:@{@"failed" :sheetMsg}];
     NSBeginAlertSheet(NSLocalizedString(titleMsg, @"Sheet Title"),
                       NSLocalizedString(@"Confirm", @"Default Button"),
                       nil,
