@@ -66,7 +66,19 @@ SYNTHESIZE_SINGLETON_FOR_CLASS(WLTrackArticlePanel);
 @synthesize idTableView;
 
 - (void)awakeFromNib {
-
+    [NSEvent addLocalMonitorForEventsMatchingMask:NSKeyUpMask handler:^NSEvent *(NSEvent *event) {
+        NSWindow *targetWindow = event.window;
+        if (targetWindow != articleWindow) {
+            return event;
+        }
+        if ([event keyCode] == 53) {
+            [self closeTrackArticleWindow:self];
+        }
+        if ([event keyCode] == 51 || [event keyCode] == 117) {
+            [self removeArticleFromDB:self];
+        }
+        return event;
+    }];
 }
 
 - (void)loadArticleFromDB: (NSString *)loginID {
@@ -113,9 +125,6 @@ SYNTHESIZE_SINGLETON_FOR_CLASS(WLTrackArticlePanel);
 }
 
 - (void) showMsgOnMainWindow:(NSString *) msg {
-    if(![msg isEqualToString:@"The articles has been stored successfully!"] || ![msg isEqualToString:@"This article is already in database!"]) {
-        [Answers logCustomEventWithName:@"articleTracking window" customAttributes:@{@"failed" : msg}];
-    }
     NSBeginAlertSheet(NSLocalizedString(@"Article Tracking", @"Sheet Title"),
                       NSLocalizedString(@"Confirm", @"Default Button"),
                       nil,
@@ -129,7 +138,6 @@ SYNTHESIZE_SINGLETON_FOR_CLASS(WLTrackArticlePanel);
 }
 
 - (void) showMsgOnArticleWindow:(NSString *) msg {
-    [Answers logCustomEventWithName:@"articleTracking window" customAttributes:@{@"failed" : msg}];
     NSBeginAlertSheet(NSLocalizedString(@"Article Tracking", @"Sheet Title"),
                       NSLocalizedString(@"Confirm", @"Default Button"),
                       nil,
@@ -333,11 +341,9 @@ SYNTHESIZE_SINGLETON_FOR_CLASS(WLTrackArticlePanel);
                 
                 [db executeUpdate: sql];
                 [db commit];
-                [Answers logCustomEventWithName:@"articleTracking window" customAttributes:@{@"action" : @"retrieve successfully"}];
                 [self performSelectorOnMainThread:@selector(showMsgOnMainWindow:) withObject:@"The articles has been stored successfully!" waitUntilDone:NO];
             }];
         } else {
-            [Answers logCustomEventWithName:@"articleTracking window" customAttributes:@{@"action" : @"open successfully"}];
             [self performSelectorOnMainThread:@selector(showMsgOnMainWindow:) withObject:@"This article is already in database!" waitUntilDone:NO];
         }
     }
@@ -349,7 +355,6 @@ SYNTHESIZE_SINGLETON_FOR_CLASS(WLTrackArticlePanel);
 }
 
 - (void)addTrackArticle:(NSWindow *) window forTerminal:(WLTerminal *) terminal {
-    [Answers logCustomEventWithName:@"articleTracking window" customAttributes:@{@"action" : @"add"}];
     if(![[terminal connection] isPTT] && (![[self getTerminalBottomLine:terminal] containsString:@"文章選讀"] || ![[self getTerminalBottomLine:terminal] containsString:@"目前顯示: 第"])){
         //show warn
         [self performSelectorOnMainThread:@selector(showMsgOnMainWindow:) withObject:@"Please make sure you're reading article in PTT" waitUntilDone:NO];
@@ -494,7 +499,6 @@ SYNTHESIZE_SINGLETON_FOR_CLASS(WLTrackArticlePanel);
         return;
     }
     if (!articleWindow) {
-        [Answers logCustomEventWithName:@"articleTracking window" customAttributes:@{@"action" : @"open successfully"}];
         [NSBundle loadNibNamed:kTrackArticlePanelNibFilename owner:self];
     }
     
